#
# spec file for package intel-media-driver
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver	7

Name:           intel-media-driver
Version:        21.3.4
Release:        150400.2.7
Summary:        Intel Media Driver for VAAPI
License:        BSD-3-Clause AND MIT
Group:          System/Libraries
URL:            https://github.com/intel/media-driver
Source:         https://github.com/intel/media-driver/archive/intel-media-%{version}.tar.gz
Source1:        generate-supplements.sh
Source2:        supplements.inc
Source3:        baselibs.conf
Patch1:         Werror-initialize-in-right-order.patch
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  gmmlib-devel >= 21.2.1
BuildRequires:  pkgconfig
#Note this is NOT libva library version!
BuildRequires:  pkgconfig(libva) >= 1.12.0
BuildRequires:  pkgconfig(pciaccess)
ExclusiveArch:  x86_64 i586
%include %{S:2}

%description
The Intel Media Driver for VAAPI is a new VA-API (Video Acceleration API)
user mode driver supporting hardware accelerated decoding, encoding, and
video post processing for GEN based graphics hardware.

%package -n libigfxcmrt%{so_ver}
Summary:        Intel Graphics C for Media Runtime Library
License:        MIT
Group:          System/Libraries

%description -n libigfxcmrt%{so_ver}
cmrtlib is a runtime library for Intel GPU render engine.

%package -n libigfxcmrt-devel
Summary:        Development files for Intel Graphics C for Media Runtime Library
License:        MIT
Group:          Development/Libraries/C and C++
Requires:       libigfxcmrt%{so_ver} = %{version}

%description -n libigfxcmrt-devel
cmrtlib is a runtime library for Intel GPU render engine.

This package contains the development headers for the library found in
libigfxcmrt%{so_ver}.

%prep
%setup -q -c -a 0
mv media-driver-* media-driver
chmod -x media-driver/*.md
pushd media-driver
%patch1 -p1
popd
%define __sourcedir media-driver
sed -i -e 's,-Werror,,' media-driver/cmrtlib/linux/CMakeLists.txt

%ifarch i586
sed -i -e 's/-m${ARCH}/-m32/' -e 's/${ARCH}/"32"/' media-driver/media_driver/cmake/linux/media_compile_flags_linux.cmake
%endif

%build
srcroot=`pwd`

%ifarch i586
export CFLAGS="%optflags -D_FILE_OFFSET_BITS=64" \
       CXXFLAGS="%optflags -D_FILE_OFFSET_BITS=64"
%endif

%cmake \
    -DBUILD_SHARED_LIBS:BOOL=OFF -DMEDIA_BUILD_FATAL_WARNINGS:BOOL=OFF
%cmake_build

%install
%cmake_install

# create a profile for exporting LIBVA_DRIVER_NAME variable
%if 0%{?suse_version} >= 1550
mkdir -p %{buildroot}%{_distconfdir}/profile.d
echo "export LIBVA_DRIVER_NAME=iHD" > %{buildroot}%{_distconfdir}/profile.d/intel-media-driver.sh
echo "setenv LIBVA_DRIVER_NAME iHD" > %{buildroot}%{_distconfdir}/profile.d/intel-media-driver.csh
%else
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
echo "export LIBVA_DRIVER_NAME=iHD" > %{buildroot}%{_sysconfdir}/profile.d/intel-media-driver.sh
echo "setenv LIBVA_DRIVER_NAME iHD" > %{buildroot}%{_sysconfdir}/profile.d/intel-media-driver.csh
%endif

%files
%doc media-driver/README.md
%license media-driver/LICENSE.md
%{_libdir}/dri
%if 0%{?suse_version} >= 1550
%dir %{_distconfdir}/profile.d
%{_distconfdir}/profile.d/*
%else
%{_sysconfdir}/profile.d/*
%endif

%files -n libigfxcmrt%{so_ver}
%{_libdir}/libigfxcmrt.so.%{so_ver}
%{_libdir}/libigfxcmrt.so.%{so_ver}.*

%files -n libigfxcmrt-devel
%doc media-driver/cmrtlib/README.md
%{_includedir}/igfxcmrt
%{_libdir}/libigfxcmrt.so
%{_libdir}/pkgconfig/igfxcmrt.pc

%changelog
* Thu Oct 28 2021 sndirsch@suse.com
- mention baselibs.conf as source in specfile
* Mon Oct 25 2021 pousaduarte@gmail.com
- Fix 32bit build (dependency for Steam in-home streaming hardware decode)
* Mon Oct  4 2021 sndirsch@suse.com
- fixed JIRA number in a previous changelog
* Wed Sep 29 2021 sndirsch@suse.com
- Update to 21.3.4
  * Fix regression:libva conformance failures since github issue#1229
* Mon Sep 27 2021 sndirsch@suse.com
- covers jira#SLE/SLE-19361
* Wed Sep 15 2021 tejas.guruswamy@opensuse.org
- Update to 21.3.3:
  * Supported platforms:
    BDW/SKL/APL(BXT)/KBL/CFL/WHL/CML/ICL/EHL/JSL/TGL/RKL/DG1/SG1/ADL-S/ADL-P
  * Extensive new features and enhancements, see README.md
- Move generated supplements list to supplements.inc
* Sat Oct 10 2020 dmueller@suse.com
- update to 20.3.0:
  * Enabled AV1 4:2:0 8bit and 10bit decoding for both driver and MSDK, up to 8K video decoding and 16K still picture decoding.
  * Added Y212 and Y412 color format support for 12 bit decoding.
  * Added several RePAK related changes for VP9 performance improvements including Pak-only RePAK and adaptive-RePAK
  * Reconstructed Surface Variant formats configuration is now handled by the media-driver
  * Added HuC Error Status Report improvements for VP9 VDEnc encoding
  * Added scaling interpolation method(nearest, bilinear, advanced)
  * Added resource usage type to specify cache policy usage
  * Enabled SFC bilinear scaling.
- Disable Werror from build, which avoids having to create build fixes
  patches for every release
- remove u_20.1.1-build-fixes.patch, u_20.2.0-build-fixes.patch (obsolete)
* Mon Aug 31 2020 sndirsch@suse.com
- Update to version 20.2.0
  * Official quarterly release including some enhancements and key
    fixes. (needed for jira#SLE/SLE-12712)
- u_20.2.0-build-fixes.patch
  * fixed more -Werror build errors
- updated Supplements lines in specfile
* Fri Aug 28 2020 sndirsch@suse.com
- moved profiles for setting env variable LIBVA_DRIVER_NAME to
  /usr/etc/profiles.d on TW (boo#1173006)
* Tue Apr 14 2020 sndirsch@suse.com
- u_20.1.1-build-fixes.patch
  * fixed remaining -Werror build errors
* Fri Apr 10 2020 bjorn.lie@gmail.com
- Update to version 20.1.1:
  * Enabled HEVC SCC Decoding.
  * VP SFC driver refactor for modularity/structure improvement.
  * Enhanced media buffer and 2D surface copy to improve
    robustness.
  * Enhanced Tile mode(Tile64, TileX, Tile4) support.
  * MOS driver refactor for modularity/robustness enhancement.
  * HEVC VDEnc Encoding
  - Added AYUV/ARGB10/Y410 format support for increased MV
    predictor range of TU1.
  - Enabled DirtyROI for better performance of static region.
  * VP9 VDEnc Encoding: Enabled scalability for better performance
    in 5k+ and range-extension real-time encoding.
  * Various bugfixes.
- For changes from previous releases, please see the included
  README.md
- Drop patches fixed upstream:
  * Werror-implicit-function-not-valid-for-C++.patch
  * U_Encode-Add-some-missing-device-IDs-for-CML-and-ICL.patch
- Rebase Werror-initialize-in-right-order.patch
* Tue Feb 25 2020 sndirsch@suse.com
- generate-supplements.sh/specfile: fixed supplements lines
  (boo#1164851)
* Thu Jan 16 2020 sndirsch@suse.com
- U_Encode-Add-some-missing-device-IDs-for-CML-and-ICL.patch
  * add support for support AML-Y (bsc#1160967)
* Thu Nov  7 2019 sndirsch@suse.com
- This release fullfills requirements for jsc#SLE-8838
* Mon Sep  2 2019 sndirsch@suse.com
- Update to version 19.2.1
  * Fixed known GPU hang issue when encoding 444 8/10bit in ICL
    issue#677
  * Fixed several compile warnings.
- Werror-implicit-function-not-valid-for-C++.patch,
  Werror-initialize-in-right-order.patch
  * needed as buildfixes
* Sat Jul  6 2019 bjorn.lie@gmail.com
- Update to version 19.2.0:
  * Release pVEInterf to fix the mem leak issue.
  * Fix memory leak during 3D surface allocation.
  * Move the lock earlier to make surface heap status aligned when
    surface is destroyd.
  * [VP] UMD_OCA Implement:
  - Add UMD_OCA support in mos.
  - Add UMD_OCA support for VP RCS case (No CM based) and
    Vebox/SFC case.
  - It is disabled by default.
  * [VP] Remove dupliatcated defines on composition.
  * Remove duplicated defines and revert part codes.
  * Full support of Gen9 CML kernel integration.
  * Stay the same compile option as Gen9.
  * Readme: update feature list for default and open source build
  * [Encode]:
  - Fix segment fault issue in Jpeg encode cases on Linux.
  - Fix Dynamic Scaling Media Reset Issue.
- Update modalias supplements.
* Mon Apr  1 2019 tiwai@suse.de
- Updated to version 18.4.1:
  * Supported Platforms:
  - BDW/SKL/APL(BXT)/KBL/CFL/WHL/CNL/ICL
  * Improvements:
  - WHL: Added WHL support and enabled its VP8 encoding.
  - ICL: Added ICL open source compute shaders for video processing.
    Enabled ICL HDR10 Tone Mapping using close source compute shaders.
  - DRM uAPI relative code is refactored to better comply to i915
    Open Source Userspace Requirement.
  - Added X11 build option detection.
  - Enabled software swizzling support to improve surface reading
    performance of vaGetImage.
  - Added ARGB,Y410 image format support.
  - Added versioning information to CMRT library.
  - BRC enhancement:
    AVC hardware encoding: added QVBR support.
    AVC shader encoding: added AVBR and max frame size BRC support.
    VP8 encoding: corrected fps calculation error.
  * Fixed issues:
  - GStreamer/gstreamer-vaapi integration:
    Fixed the issue about KBL HEVC P010_10LE encoding kernel state
    initialization failure for CODECHAL_HEVC_MBENC_PENC.
    Fixed the issue about aspect ratio being unable to retain in
    video processsing PutSurface for vaapisink display.
  - Corrected RT format reporting for HEVC main10 profile.
  - Corrected caps reporting of max width/height for VP9 decoding
    from 2k (2048x2048) to 8k (8192x8192).
- Add sub-packages libigfxcmrt7 and libigfxcmrt-devel
- Updated supplements accordingly
* Tue Nov 13 2018 sndirsch@suse.com
- added hardware supplements in order to install the package on
  appropriate hardware (Broadwell, Skylake, Broxton/Apollo Lake,
  Kaby Lake, Coffee Lake, Cannonlake, Ice Lake at this time)
- added script to generate the above information easily
* Wed Nov  7 2018 tiwai@suse.de
- Updated to version 18.3.0:
  * Adding ICL support
  * Adding dynamic loading support of Gmmlib
  * Better support to ffmpeg and gstreamer:
    + AVC low power encoding
    + MPEG2 encoding
    + VP8 decoding
    + VC1 decoding
    + JPEG encoding and decoding
  * Adding Dockerfile and docker images
- Use shared lib of gmmlib; added buildreq accordingly
* Tue Jul 10 2018 tiwai@suse.de
- initial package: media-driver Q2'18 release
